==> php54-owncloud-7.0.4.tgz: share/owncloud/apps/calendar/l10n/gl.php <==
<?php $TRANSLATIONS = array(
"Not all calendars are completely cached" => "Non todos os calendarios están completamente na caché",
"Everything seems to be completely cached" => "Rematouse e todo está na caché",
"No calendars found." => "Non se atoparon calendarios.",
"No events found." => "Non se atoparon actividades.",
"Wrong calendar" => "Calendario trabucado",
"You do not have the permissions to edit this event." => "Non ten permiso para editar esta actividade.",
"The file contained either no events or all events are already saved in your calendar." => "Ou ben o ficheiro non ten actividades ou todas elas están anotadas xa no seu calendario.",
"events have been saved in the new calendar" => "as actividades foron gardadas no novo calendario",
"Import failed" => "Produciuse un fallo na importación",
"events have been saved in your calendar" => "as actividades foron gardadas no seu calendario",
"New Timezone:" => "Novo fuso horario:",
"Timezone changed" => "Cambiouse o fuso horario",
"Invalid request" => "Petición incorrecta",
"Calendar" => "Calendario",
"Deletion failed" => "Produciuse un fallo ao eliminar",
"ddd d MMMM[ yyyy]{ - [ddd d] MMMM yyyy}" => "ddd d MMMM[ yyyy]{ - [ddd d] MMMM yyyy}",
"ddd d MMMM[ yyyy] HH:mm{ - [ ddd d MMMM yyyy] HH:mm}" => "ddd d MMMM[ yyyy] HH:mm{ - [ ddd d MMMM yyyy] HH:mm}",
"group" => "grupo",
"can edit" => "pode editar",
"can share" => "pode compartir",
"ddd" => "ddd",
"ddd M/d" => "ddd d/M",
"dddd M/d" => "dddd d/M",
"MMMM yyyy" => "MMMM yyyy",
"MMM d[ yyyy]{ '–'[ MMM] d yyyy}" => "MMM d[ yyyy]{ '–'[ MMM] d yyyy}",
"dddd, MMM d, yyyy" => "dddd, d MMM, yyyy",
"Sunday" => "domingo",
"Monday" => "luns",
"Tuesday" => "martes",
"Wednesday" => "mércores",
"Thursday" => "xoves",
"Friday" => "venres",
"Saturday" => "sábado",
"Sun." => "dom.",
"Mon." => "lun.",
"Tue." => "mar.",
"Wed." => "mér.",
"Thu." => "xov.",
"Fri." => "ven.",
"Sat." => "sáb.",
"January" => "xaneiro",
"February" => "febreiro",
"March" => "marzo",
"April" => "abril",
"May" => "maio",
"June" => "xuño",
"July" => "xullo",
"August" => "agosto",
"September" => "setembro",
"October" => "outubro",
"November" => "novembro",
"December" => "decembro",
"Jan." => "xan.",
"Feb." => "feb.",
"Mar." => "mar.",
"Apr." => "abr.",
"May." => "mai.",
"Jun." => "xuñ.",
"Jul." => "xul.",
"Aug." => "ago.",
"Sep." => "set.",
"Oct." => "out.",
"Nov." => "nov.",
"Dec." => "dec.",
"All day" => "Todo o dia",
"New Calendar" => "Novo calendario",
"Missing or invalid fields" => "Faltan ou son campos incorrectos",
"Title" => "Título",
"From Date" => "Desde a data",
"From Time" => "Desde a hora",
"To Date" => "Para a data",
"To Time" => "Para a hora",
"The event ends before it starts" => "A actividade remata antes de iniciarse",
"There was a database fail" => "Produciuse un erro na base de datos",
"Interval is not valid. It must be a positive integer!" => "O intervalo é incorrecto. Ten que ser un enteiro positivo!",
"Birthday" => "Aniversario",
"Business" => "Traballo",
"Call" => "Chamada",
"Clients" => "Clientes",
"Deliverer" => "Remitente",
"Holidays" => "Vacacións",
"Ideas" => "Ideas",
"Journey" => "Viaxe",
"Jubilee" => "Aniversario especial",
"Meeting" => "Xuntanza",
"Other" => "Outro",
"Personal" => "Persoal",
"Projects" => "Proxectos",
"Questions" => "Preguntas",
"Work" => "Traballo",
"by" => "por",
"unnamed" => "sen nome",
"You do not have the permissions to update this calendar." => "Non ten permiso para actualizar este calendario.",
"You do not have the permissions to delete this calendar." => "Non ten permiso para eliminar este calendario.",
"You do not have the permissions to add to this calendar." => "Non ten permiso para engadir este calendario.",
"You do not have the permissions to add events to this calendar." => "Non ten permiso para engadir novas actividades neste calendario.",
"You cannot add non-public events to a shared calendar." => "Non pode engadir actividades que non sexan públicas a un calendario compartido.",
"You do not have the permissions to delete this event." => "Non ten permiso para eliminar esta actividade.",
"Busy" => "Ocupado",
"Show full event" => "Amosar todas actividades",
"Show only busy" => "Amosar só o ocupado",
"Hide event" => "Agochar a actividade",
"Does not repeat" => "Non se repite",
"Daily" => "A diario",
"Weekly" => "Semanalmente",
"Every Weekday" => "Todas as semanas",
"Bi-Weekly" => "Cada dúas semanas",
"Monthly" => "Mensual",
"Yearly" => "Anual",
"never" => "nunca",
"by occurrences" => "por acontecementos",
"by date" => "pola data",
"by monthday" => "polo día do mes",
"by weekday" => "polo día da semana",
"events week of month" => "actividades semanais do mes",
"first" => "primeiro",
"second" => "segundo",
"third" => "terceiro",
"fourth" => "cuarto",
"fifth" => "quinto",
"last" => "último",
"by events date" => "pola data das actividades",
"by yearday(s)" => "polo(s) dia(s) do ano",
"by weeknumber(s)" => "polos(s) número(s) de semana",
"by day and month" => "por día e mes",
"Contact birthdays" => "Aniversarios dos contactos",
"Date" => "Data",
"Cal." => "Cal.",
"Day" => "Día",
"Week" => "Semana",
"Month" => "Mes",
"Today" => "Hoxe",
"CalDav Link" => "Ligazón CalDav",
"Timezone" => "Fuso horario",
"Update timezone automatically" => "Actualizar o fuso horario automaticamente",
"Time format" => "Formato da hora",
"24h" => "24h",
"12h" => "12h",
"Start week on" => "Comezar a semana o ",
"Cache" => "Caché",
"Clear cache for repeating events" => "Limpar a caché para as actividades que se repiten",
"Primary CalDAV address" => "Enderezo CalDAV primario",
"iOS/OS X CalDAV address" => "Enderezo iOS/OS X CalDAV",
"Share Calendar" => "Compartir o calendario",
"Download" => "Descargar",
"Edit" => "Editar",
"Delete" => "Eliminar",
"New calendar" => "Novo calendario",
"Edit calendar" => "Editar o calendario",
"Edit event" => "Editar a actividade",
"Save event" => "Gardar a actividade",
"Delete event" => "Eliminar a actividade",
"Eventinfo" => "Info. da actividade",
"Repeating" => "Repetido",
"Alarm" => "Alarma",
"Attendees" => "Participantes",
"Share" => "Compartir",
"Title of the Event" => "Título da actividade",
"from" => "desde",
"to" => "ata",
"All Day Event" => "Actividades de todo o día",
"Advanced options" => "Opcións avanzadas",
"Location" => "Lugar",
"Categories (separate by comma)" => "Categorías (separadas por comas)",
"Edit categories" => "Editar as categorías",
"Description" => "Descrición",
"Export event" => "Exportar a actividade",
"Repeat" => "Repetir",
"Advanced" => "Avanzado",
"Select weekdays" => "Seleccionar os días da semana",
"Select days" => "Seleccionar os días",
"and the events day of year." => "e as actividades diarias do ano.",
"and the events day of month." => "e as actividades diarias do mes.",
"Select months" => "Seleccionar os meses",
"Select weeks" => "Seleccionar as semanas",
"and the events week of year." => "e as actividades semanais do ano.",
"Interval" => "Intervalo",
"End" => "Fin",
"occurrences" => "acontecementos",
"Visibility to people shared with" => "Visibilidade da xente que comparte con",
"create a new calendar" => "crear un novo calendario",
"Import a calendar file" => "Importar un ficheiro de calendario",
"Please choose a calendar" => "Escolla un calendario",
"Name of new calendar" => "Nome do novo calendario",
"Take an available name!" => "Escolla un nome dispoñíbel",
"A Calendar with this name already exists. If you continue anyhow, these calendars will be merged." => "Xa hai un calendario con ese nome. Sen lle cambiar o nome xuntaranse os dous calendarios.",
"Remove all events from the selected calendar" => "Eliminar todas as actividades do calendario escollido.",
"Import" => "Importar",
"Close Dialog" => "Pechar o diálogo",
"Create a new event" => "Crear unha nova actividade",
"Create event" => "Crear unha actividade",
"Share with user or group" => "Compartir cun usuario ou grupo",
"Unshare" => "Deixar de compartir",
"Not shared with anyone" => "Non compartido con ninguén",
"Send Email" => "Enviar correo",
"Shared via calendar" => "Compartir por calendario",
"Not shared with anyone via calendar" => "Non compartido con ninguén a través do calendario",
"View an event" => "Ver unha actividade",
"Category" => "Categoría",
"No categories selected" => "Non foi seleccionada ningunha categoría",
"%s of %s" => "%s de %s",
"Access Class" => "Clase de acceso",
"From" => "Desde",
"at" => "a",
"To" => "a"
);

==> php54-owncloud-8.0.3.tgz: share/owncloud/apps/calendar/l10n/gl.php <==
<?php
$TRANSLATIONS = array(
"Not all calendars are completely cached" => "Non todos os calendarios están completamente na caché",
"Everything seems to be completely cached" => "Rematouse e todo está na caché",
"No calendars found." => "Non se atoparon calendarios.",
"No events found." => "Non se atoparon actividades.",
"Wrong calendar" => "Calendario trabucado",
"You do not have the permissions to edit this event." => "Non ten permiso para editar esta actividade.",
"The file contained either no events or all events are already saved in your calendar." => "Ou ben o ficheiro non ten actividades ou todas elas están anotadas xa no seu calendario.",
"events have been saved in the new calendar" => "as actividades foron gardadas no novo calendario",
"Import failed" => "Produciuse un fallo na importación",
"events have been saved in your calendar" => "as actividades foron gardadas no seu calendario",
"New Timezone:" => "Novo fuso horario:",
"Timezone changed" => "Cambiouse o fuso horario",
"Invalid request" => "Petición incorrecta",
"Calendar" => "Calendario",
"Error sending mail" => "Produciuse un erro ao enviar o correo",
"Deletion failed" => "Produciuse un fallo ao eliminar",
"ddd d MMMM[ yyyy]{ - [ddd d] MMMM yyyy}" => "ddd d MMMM[ yyyy]{ - [ddd d] MMMM yyyy}",
"ddd d MMMM[ yyyy] HH:mm{ - [ ddd d MMMM yyyy] HH:mm}" => "ddd d MMMM[ yyyy] HH:mm{ - [ ddd d MMMM yyyy] HH:mm}",
"Do you really want to delete this calendar?" => "Confirma que quere eliminar este calendario?",
"group" => "grupo",
"can edit" => "pode editar",
"can share" => "pode compartir",
"ddd" => "ddd",
"ddd M/d" => "ddd d/M",
"dddd M/d" => "dddd d/M",
"MMMM yyyy" => "MMMM yyyy",
"MMM d[ yyyy]{ '–'[ MMM] d yyyy}" => "MMM d[ yyyy]{ '–'[ MMM] d yyyy}",
"dddd, MMM d, yyyy" => "dddd, d MMM, yyyy",
"Sunday" => "domingo",
"Monday" => "luns",
"Tuesday" => "martes",
"Wednesday" => "mércores",
"Thursday" => "xoves",
"Friday" => "venres",
"Saturday" => "sábado",
"Sun." => "dom.",
"Mon." => "lun.",
"Tue." => "mar.",
"Wed." => "mér.",
"Thu." => "xov.",
"Fri." => "ven.",
"Sat." => "sáb.",
"January" => "xaneiro",
"February" => "febreiro",
"March" => "marzo",
"April" => "abril",
"May" => "maio",
"June" => "xuño",
"July" => "xullo",
"August" => "agosto",
"September" => "setembro",
"October" => "outubro",
"November" => "novembro",
"December" => "decembro",
"Jan." => "xan.",
"Feb." => "feb.",
"Mar." => "mar.",
"Apr." => "abr.",
"May." => "mai.",
"Jun." => "xuñ.",
"Jul." => "xul.",
"Aug." => "ago.",
"Sep." => "set.",
"Oct." => "out.",
"Nov." => "nov.",
"Dec." => "dec.",
"All day" => "Todo o dia",
"New Calendar" => "Novo calendario",
"Missing or invalid fields" => "Faltan ou son campos incorrectos",
"Title" => "Título",
"From Date" => "Desde a data",
"From Time" => "Desde a hora",
"To Date" => "Para a data",
"To Time" => "Para a hora",
"The event ends before it starts" => "A actividade remata antes de iniciarse",
"There was a database fail" => "Produciuse un erro na base de datos",
"Interval is not valid. It must be a positive integer!" => "O intervalo é incorrecto. Ten que ser un enteiro positivo!",
"Birthday" => "Aniversario",
"Business" => "Traballo",
"Call" => "Chamada",
"Clients" => "Clientes",
"Deliverer" => "Remitente",
"Holidays" => "Vacacións",
"Ideas" => "Ideas",
"Journey" => "Viaxe",
"Jubilee" => "Aniversario especial",
"Meeting" => "Xuntanza",
"Other" => "Outro",
"Personal" => "Persoal",
"Projects" => "Proxectos",
"Questions" => "Preguntas",
"Work" => "Traballo",
"by" => "por",
"unnamed" => "sen nome",
"You do not have the permissions to update this calendar." => "Non ten permiso para actualizar este calendario.",
"You do not have the permissions to delete this calendar." => "Non ten permiso para eliminar este calendario.",
"You do not have the permissions to add to this calendar." => "Non ten permiso para engadir este calendario.",
"You do not have the permissions to add events to this calendar." => "Non ten permiso para engadir novas actividades neste calendario.",
"You cannot add non-public events to a shared calendar." => "Non pode engadir actividades que non sexan públicas a un calendario compartido.",
"You do not have the permissions to delete this event." => "Non ten permiso para eliminar esta actividade.",
"Busy" => "Ocupado",
"Show full event" => "Amosar todas actividades",
"Show only busy" => "Amosar só o ocupado",
"Hide event" => "Agochar a actividade",
"Does not repeat" => "Non se repite",
"Daily" => "A diario",
"Weekly" => "Semanalmente",
"Every Weekday" => "Todas as semanas",
"Bi-Weekly" => "Cada dúas semanas",
"Monthly" => "Mensual",
"Yearly" => "Anual",
"never" => "nunca",
"by occurrences" => "por acontecementos",
"by date" => "pola data",
"by monthday" => "polo día do mes",
"by weekday" => "polo día da semana",
"events week of month" => "actividades semanais do mes",
"first" => "primeiro",
"second" => "segundo",
"third" => "terceiro",
"fourth" => "cuarto",
"fifth" => "quinto",
"last" => "último",
"by events date" => "pola data das actividades",
"by yearday(s)" => "polo(s) dia(s) do ano",
"by weeknumber(s)" => "polos(s) número(s) de semana",
"by day and month" => "por día e mes",
"Contact birthdays" => "Aniversarios dos contactos",
"Date" => "Data",
"Day" => "Día",
"Week" => "Semana",
"Month" => "Mes",
"Today" => "Hoxe",
"CalDav Link" => "Ligazón CalDav",
"Timezone" => "Fuso horario",
"Update timezone automatically" => "Actualizar o fuso horario automaticamente",
"Time format" => "Formato da hora",
"24h" => "24h",
"12h" => "12h",
"Start week on" => "Comezar a semana o ",
"Cache" => "Caché",
"Clear cache for repeating events" => "Limpar a caché para as actividades que se repiten",
"Primary CalDAV address" => "Enderezo CalDAV primario",
"iOS/OS X CalDAV address" => "Enderezo iOS/OS X CalDAV",
"Share Calendar" => "Compartir o calendario",
"Download" => "Descargar",
"Edit" => "Editar",
"Delete" => "Eliminar",
"New calendar" => "Novo calendario",
"Edit calendar" => "Editar o calendario",
"Edit event" => "Editar a actividade",
"Save event" => "Gardar a actividade",
"Delete event" => "Eliminar a actividade",
"Eventinfo" => "Info. da actividade",
"Repeating" => "Repetido",
"Alarm" => "Alarma",
"Attendees" => "Participantes",
"Share" => "Compartir",
"Title of the Event" => "Título da actividade",
"from" => "desde",
"to" => "ata",
"All Day Event" => "Actividades de todo o día",
"Advanced options" => "Opcións avanzadas",
"Location" => "Lugar",
"Categories (separate by comma)" => "Categorías (separadas por comas)",
"Edit categories" => "Editar as categorías",
"Description" => "Descrición",
"Export event" => "Exportar a actividade",
"Repeat" => "Repetir",
"Advanced" => "Avanzado",
"Select weekdays" => "Seleccionar os días da semana",
"Select days" => "Seleccionar os días",
"and the events day of year." => "e as actividades diarias do ano.",
"and the events day of month." => "e as actividades diarias do mes.",
"Select months" => "Seleccionar os meses",
"Select weeks" => "Seleccionar as semanas",
"and the events week of year." => "e as actividades semanais do ano.",
"Interval" => "Intervalo",
"End" => "Fin",
"occurrences" => "acontecementos",
"Visibility to people shared with" => "Visibilidade da xente que comparte con",
"create a new calendar" => "crear un novo calendario",
"Import a calendar file" => "Importar un ficheiro de calendario",
"Please choose a calendar" => "Escolla un calendario",
"Name of new calendar" => "Nome do novo calendario",
"Take an available name!" => "Escolla un nome dispoñíbel",
"A Calendar with this name already exists. If you continue anyhow, these calendars will be merged." => "Xa hai un calendario con ese nome. Sen lle cambiar o nome xuntaranse os dous calendarios.",
"Remove all events from the selected calendar" => "Eliminar todas as actividades do calendario escollido.",
"Import" => "Importar",
"Close Dialog" => "Pechar o diálogo",
"Create a new event" => "Crear unha nova actividade",
"Create event" => "Crear unha actividade",
"Share with user or group" => "Compartir cun usuario ou grupo",
"Unshare" => "Deixar de compartir",
"Not shared with anyone" => "Non compartido con ninguén",
"Send Email" => "Enviar correo",
"Shared via calendar" => "Compartir por calendario",
"Not shared with anyone via calendar" => "Non compartido con ninguén a través do calendario",
"View an event" => "Ver unha actividade",
"Category" => "Categoría",
"No categories selected" => "Non foi seleccionada ningunha categoría",
"%s of %s" => "%s de %s",
"Access Class" => "Clase de acceso",
"From" => "Desde",
"at" => "a",
"To" => "a"
);
$PLURAL_FORMS = "nplurals=2; plural=(n != 1);";
